Emacs highlighter
-----------------

Preliminary DIP syntax highliter for Emacs based on the Python mode is available in the main source code repository:  `dip-mode.el <https://github.com/vrtulka23/scinumtools/tree/main/tools/emacs/dip-mode.el>`_.